require_relative "../spec_helper"


describe By2::Options do
  context("by2") do
    it "outputs help options" do
      pending
    end
  end

  context("by2 -i IP") do
    it "parses ip option" do
      options = By2::Options.parse(["-i", "128.32.72.190"])
      options[:ip].should eql("128.32.72.190")
    end
  end

  context("by2 -s SRC_IP -d DST_IP") do
    it "parses src_ip" do
      options = By2::Options.parse(["-s", "128.32.72.190"])
      options[:src_ip].should eql("128.32.72.190")
    end

    it "parses dst_ip" do
      options = By2::Options.parse(["-d", "128.32.72.190"])
      options[:dst_ip].should eql("128.32.72.190")
    end

    it "parses src and dst ips" do
      options = By2::Options.parse(["-d", "128.32.72.191", "-s", "128.32.72.190"])

      options[:src_ip].should eql("128.32.72.190")
      options[:dst_ip].should eql("128.32.72.191")
    end
  end

  context("by2 -s SRC_IP:SRC_PORT -d DST_IP:DST_PORT") do
    it "ip parses src_ip with port" do
      options = By2::Options.parse(["-s", "128.32.72.190:80"])

      options[:src_ip].should eql("128.32.72.190")
      options[:src_port].should eql("80")
    end

    it "ip parses dst_ip with port" do
      options = By2::Options.parse(["-d", "128.32.72.190:80"])

      options[:dst_ip].should eql("128.32.72.190")
      options[:dst_port].should eql("80")
    end

    it "ip parses src and dst ips with port" do
      options = By2::Options.parse(["-s", "128.32.72.190:80", "-d", "128.32.72.191:81"])

      options[:src_ip].should eql("128.32.72.190")
      options[:src_port].should eql("80")
      options[:dst_ip].should eql("128.32.72.191")
      options[:dst_port].should eql("81")
    end
  end

  context("by2 -m SRC_IP -> DST_IP") do
    it "parses src and dst ips in -> format" do
      options = By2::Options.parse(["-m", "128.32.72.190 -> 128.32.72.191"])

      options[:src_ip].should eql("128.32.72.190")
      options[:dst_ip].should eql("128.32.72.191")
      options[:src_port].should be_nil
      options[:dst_port].should be_nil
    end
  end

  context("by2 -m SRC_IP:SRC_PORT -> DST_IP:DST_PORT") do
    it "parses src and dst ips and ports in -> format" do
      options = By2::Options.parse(["-m", "128.32.72.190:80 -> 128.32.72.191:81"])

      options[:src_ip].should eql("128.32.72.190")
      options[:src_port].should eql("80")
      options[:dst_ip].should eql("128.32.72.191")
      options[:dst_port].should eql("81")
    end
  end

  context("by2 -t DATE") do
    it "parses date" do
      options = By2::Options.parse(["-t", "2014-02-01"])
      options[:date].should eql("2014-02-01")

      options[:start_date].should be_nil
      options[:end_date].should be_nil
    end
  end

  context("by2 -t START_DATE:END_DATE") do
    it "parses date with a range" do
      options = By2::Options.parse(["-t", "2014-02-01:"])
      options[:start_date].should eql("2014-02-01")
      options[:end_date].should be_nil
      options[:date].should be_nil

      options = By2::Options.parse(["-t", "2014-02-01:2014-02-07"])
      options[:start_date].should eql("2014-02-01")
      options[:end_date].should eql("2014-02-07")
      options[:date].should be_nil
    end
  end
end
